==> tcllib_1.20+dfsg.orig.tar.xz: tcllib-1.20/embedded/index.md <==
<div class='fossil-doc' data-title='Tcl Library Source Code'>

<h1 align="center">Tcl Library Source Code</h1>

<center>
Packages - [Table Of Contents](md/toc.md)
&nbsp;&nbsp;&nbsp;
[Keyword Index](md/index.md)
</center>

<center>
	<form action='../../../docsrch' method='GET'>
	<input type="text" name="s" size="40" autofocus>
	<input type="submit" value="Search Package Documentation">
	</form>
</center>

## Guides to Tcllib

   * [Tcl Community - Kind Communication](md/tcllib/files/devdoc/tcl_community_communication.md)
   * [License](md/tcllib/files/devdoc/tcllib_license.md)
   * [How To Get The Sources](md/tcllib/files/devdoc/tcllib_sources.md)
   * [How To Build And Install Tcllib](md/tcllib/files/devdoc/tcllib_installer.md)
   * [The Developer's Guide](md/tcllib/files/devdoc/tcllib_devguide.md)
   * [The Release Manager's Guide](md/tcllib/files/devdoc/tcllib_releasemgr.md)

## Discussion & Contact

Tcllib has two
[mailing lists](https://sourceforge.net/p/tcllib/mailman/).

One for notifications (commits, ticket changes), the other for general
discussion. These are managed at SourceForge, at the aforementioned
link. A few direct links for various topics:

|tcllib-bugs| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-bugs) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-bugs) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-bugs)|
|tcllib-devel| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-devel) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-devel) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-devel)|

## Feedback

Please go to and use our
[Local Trackers](../../../reportlist).
They are for

   * Bugs,
   * Patches, and	 
   * Ideas & Feature Requests.

## Releases

   * [Current](../../../technote/0b2528ed32f54c4a8f08951aaa11ff60b3843630) __1.19 (Feb 16, 2018)__
   * [Past Releases](../../../wiki?name=Past+Releases)
   * [Development Snapshots](../../../wiki?name=Development+Snapshots)
   * [@ SourceForge](https://sourceforge.net/projects/tcllib/files/)

## Related Repositories

   * [Tklib](../../../../tklib)
   * [Tcl Apps](../../../../tclapps)
   * [Tcl Bench](../../../../tclbench)
   * [Multicolumn Listbox](../../../../mclistbox)
   * [Widget](../../../../widget)
   * [BWidget](../../../../bwidget)


## See also

   * [Landing page for this package at the Tcl Developer eXchange](http://www.tcl.tk/software/tcllib/)

==> tcllib_2.0+dfsg.orig.tar.xz: tcllib-2.0/embedded/index.md <==
<div class='fossil-doc' data-title='Tcl Library Source Code'>

<h1 align="center">Tcl Library Source Code</h1>

<center>
Packages - [Table Of Contents](md/toc.md)
&nbsp;&nbsp;&nbsp;
[Keyword Index](md/index.md)
</center>

<center>
	<form action='../../../docsrch' method='GET'>
	<input type="text" name="s" size="40" autofocus>
	<input type="submit" value="Search Package Documentation">
	</form>
</center>

## Releases / Downloads

The download links are on the referenced pages.

   * [Trunk Head](head.md)
   * [Current Release](../../../technote/7a047636411e9c9d8e1410ddee0fb02d1458a7c0) __1.21 (May 7, 2022)__
   * [Past Releases](../../../wiki?name=Past+Releases)
   * [Development Snapshots](../../../wiki?name=Development+Snapshots)
   * [@ SourceForge](https://sourceforge.net/projects/tcllib/files/)

## Guides to Tcllib

   * [Tcl Community - Kind Communication](md/tcllib/files/devdoc/tcl_community_communication.md)
   * [License](md/tcllib/files/devdoc/tcllib_license.md)
   * [How To Get The Sources](md/tcllib/files/devdoc/tcllib_sources.md)
   * [How To Build And Install Tcllib](md/tcllib/files/devdoc/tcllib_installer.md)
   * [The Developer's Guide](md/tcllib/files/devdoc/tcllib_devguide.md)
   * [The Release Manager's Guide](md/tcllib/files/devdoc/tcllib_releasemgr.md)

## Discussion & Contact

Tcllib has two
[mailing lists](https://sourceforge.net/p/tcllib/mailman/).

One for notifications (commits, ticket changes), the other for general
discussion. These are managed at SourceForge, at the aforementioned
link. A few direct links for various topics:

|tcllib-bugs| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-bugs) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-bugs) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-bugs)|
|tcllib-devel| : |[Subscribe](https://lists.sourceforge.net/lists/listinfo/tcllib-devel) [Archive](https://sourceforge.net/p/tcllib/mailman/tcllib-devel) [Search](https://sourceforge.net/p/tcllib/mailman/search/?mail_list=tcllib-devel)|

## Related Repositories

   * [Tklib](../../../../tklib)
   * [Tcl Apps](../../../../tclapps)
   * [Tcl Bench](../../../../tclbench)
   * [Multicolumn Listbox](../../../../mclistbox)
   * [Widget](../../../../widget)
   * [BWidget](../../../../bwidget)

## Feedback

Please go to and use our
[Local Trackers](../../../reportlist).
They are for

   * Bugs,
   * Patches, and	 
   * Ideas & Feature Requests.

## See also

   * [Landing page for this package at the Tcl Developer eXchange](http://www.tcl.tk/software/tcllib/)
